﻿using ScottPlot;
using System.Diagnostics;
using System.Drawing;
using Point = KMeansBase.Point;

namespace kMeans;

public static class Helper
{
    public static Plot CreatePlot(IEnumerable<Point> points, IEnumerable<Point> centroids)
    {
        var plot = new Plot();
        plot.Legend(true, Alignment.UpperRight);
        var colors = new Dictionary<int, Color>();
        var colorGroups = points.GroupBy(x => x.ClusterId);
        foreach (var clusterGroup in colorGroups)
        {
            var color = plot.GetNextColor();
            colors.Add(clusterGroup.Key, color);
            var xs = clusterGroup.Select(p => p.X).ToArray();
            var ys = clusterGroup.Select(p => p.Y).ToArray();
            plot.AddScatterPoints(xs, ys, color);
        }

        const MarkerShape marker = MarkerShape.cross;
        const float size = 10f;
        foreach (var (x, y, clusterId) in centroids)
        {
            var color = colors.TryGetValue(clusterId, out var c) ? c : plot.GetNextColor();
            plot.AddScatterPoints(new[] { x }, new[] { y }, color, size, marker, $"ClusterId: {clusterId}");
        }

        return plot;
    }

    public static void ExportPlot(Plot plot, string path)
    {
        plot.SaveFig(path);
    }

    public static void PreviewPlot(string path)
    {
        using var p = Process.Start(new ProcessStartInfo(path) { UseShellExecute = true });
        p?.WaitForExit();
    }
}